/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of Simonstrator.KOM.
 * 
 * Simonstrator.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */


package de.tudarmstadt.maki.simonstrator.api.component.vehicular.roadnetwork.paths;

import java.util.List;

import de.tudarmstadt.maki.simonstrator.api.component.vehicular.roadnetwork.RoadNetwork;
import de.tudarmstadt.maki.simonstrator.api.component.vehicular.roadnetwork.RoadNetworkEdge;
import de.tudarmstadt.maki.simonstrator.api.component.vehicular.roadnetwork.RoadNetworkRoute;

/**
 * @author Tobias Meuser (tobias.meuser@kom.tu-darmstadt.de)
 * @version 1.0 at 28.11.2017
 *
 */
public interface PathDetectionAlgorithm {
	List<ProbabilisticRoadNetworkRoute> findAllRoutes(RoadNetwork pNetwork, RoadNetworkEdge pCurrentPosition,
			RoadNetworkEdge pDestination);

	public class ProbabilisticRoadNetworkRoute {
		private final double _probability;
		private final RoadNetworkRoute _route;
		private final double _length;

		public ProbabilisticRoadNetworkRoute(double pProbability, RoadNetworkRoute pRoute) {
			_probability = pProbability;
			_route = pRoute;
			_length = pRoute.getTravelTime();
		}

		public double getProbability() {
			return _probability;
		}

		public RoadNetworkRoute getRoute() {
			return _route;
		}

		public double getLength() {
			return _length;
		}

		@Override
		public String toString() {
			return _route.toString() + " with probability of " + _probability;
		}
	}
}
